==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/RozliczenieSwiadczenieKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class RozliczenieSwiadczenieKey extends GenericDPSObject {
    /**
     * ROZLICZENIE_SWIADCZENIE.ROZLICZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long rozliczenieId;

    /**
     * ROZLICZENIE_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ROZLICZENIE_SWIADCZENIE.ROZLICZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getRozliczenieId() {
        return rozliczenieId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ROZLICZENIE_SWIADCZENIE.ROZLICZENIE_ID
     *
     * @param rozliczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setRozliczenieId(Long rozliczenieId) {
        this.rozliczenieId = rozliczenieId;
    }

    /**
     * @return ROZLICZENIE_SWIADCZENIE.SWIADCZENIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * ROZLICZENIE_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RozliczenieSwiadczenieKey other = (RozliczenieSwiadczenieKey) that;
        return (this.getRozliczenieId() == null ? other.getRozliczenieId() == null : this.getRozliczenieId().equals(other.getRozliczenieId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getRozliczenieId() == null) ? 0 : getRozliczenieId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", rozliczenieId=").append(rozliczenieId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/RozliczenieSwiadczenieKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class RozliczenieSwiadczenieKey extends GenericDPSObject {
    /**
     * ROZLICZENIE_SWIADCZENIE.ROZLICZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long rozliczenieId;

    /**
     * ROZLICZENIE_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long swiadczenieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ROZLICZENIE_SWIADCZENIE.ROZLICZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getRozliczenieId() {
        return rozliczenieId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ROZLICZENIE_SWIADCZENIE.ROZLICZENIE_ID
     *
     * @param rozliczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setRozliczenieId(Long rozliczenieId) {
        this.rozliczenieId = rozliczenieId;
    }

    /**
     * @return ROZLICZENIE_SWIADCZENIE.SWIADCZENIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSwiadczenieId() {
        return swiadczenieId;
    }

    /**
     * ROZLICZENIE_SWIADCZENIE.SWIADCZENIE_ID
     *
     * @param swiadczenieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSwiadczenieId(Long swiadczenieId) {
        this.swiadczenieId = swiadczenieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        RozliczenieSwiadczenieKey other = (RozliczenieSwiadczenieKey) that;
        return (this.getRozliczenieId() == null ? other.getRozliczenieId() == null : this.getRozliczenieId().equals(other.getRozliczenieId()))
            && (this.getSwiadczenieId() == null ? other.getSwiadczenieId() == null : this.getSwiadczenieId().equals(other.getSwiadczenieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getRozliczenieId() == null) ? 0 : getRozliczenieId().hashCode());
        result = prime * result + ((getSwiadczenieId() == null) ? 0 : getSwiadczenieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", rozliczenieId=").append(rozliczenieId);
        sb.append(", swiadczenieId=").append(swiadczenieId);
        sb.append("]");
        return sb.toString();
    }
}
